@@ -26,7 +26,7 @@
 #include <QString>
 #include <QTemporaryFile>
 
-#include <QtTest>
+#include <QTest>
 
 using namespace Wacom;
 
